%global goipath         github.com/containerd

Summary:        An industry-standard container runtime
Name:           containerd
Version:        1.6.9
Release:        4%{?dist}
License:        ASL 2.0
URL:            https://containerd.io
Source0:        https://github.com/containerd/containerd/archive/refs/tags/v%{version}.tar.gz

BuildRequires:  golang glibc-static make btrfs-progs-devel git systemd-rpm-macros
BuildRequires:  go-rpm-macros go-md2man
Requires:       runc

%description
containerd is an industry-standard container runtime with an emphasis on
simplicity, robustness and portability.  It is available as a daemon for Linux
and Windows, which can manage the complete container lifecycle of its host
system: image transfer and storage, container execution and supervision,
low-level storage and network attachments, etc.

%prep
%autosetup -n %{name}-%{version} -p1 -Sgit
sed -i "s|/usr/local/bin/containerd|/usr/bin/containerd|" containerd.service

%build
export LDFLAGS="-X %{goipath}/containerd/version.Version=%{version} "
export GOPATH="$PWD/.gopath"
mkdir -p $GOPATH/src/%{goipath}
ln -sfn $PWD $GOPATH/src/%{goipath}/containerd
for cmd in cmd/* ; do
    %gobuild -o bin/$(basename $cmd) %{goipath}/containerd/$cmd
done

mkdir _man
go-md2man -in docs/man/containerd-config.8.md -out _man/containerd-config.8
go-md2man -in docs/man/containerd-config.toml.5.md -out _man/containerd-config.toml.5
bin/gen-manpages containerd.8 _man
bin/gen-manpages ctr.8 _man

%install
install -d %{buildroot}%{_bindir}
install -p -m 755 bin/* %{buildroot}%{_bindir}/
install -D -p -m 0644 _man/containerd.8 %{buildroot}%{_mandir}/man8/containerd.8
install -D -p -m 0644 _man/containerd-config.8 %{buildroot}%{_mandir}/man8/containerd-config.8
install -D -p -m 0644 _man/ctr.8 %{buildroot}%{_mandir}/man8/ctr.8
install -D -p -m 0644 _man/containerd-config.toml.5 %{buildroot}%{_mandir}/man5/containerd-config.toml.5
install -D -p -m 0644 containerd.service %{buildroot}%{_unitdir}/containerd.service
mkdir -p %{buildroot}%{_sharedstatedir}/containerd/opt

%post
%systemd_post containerd.service

%preun
%systemd_preun containerd.service

%postun
%systemd_postun_with_restart containerd.service

%files
%license LICENSE NOTICE
%doc docs ROADMAP.md SCOPE.md code-of-conduct.md BUILDING.md
%doc README.md RELEASES.md
%{_unitdir}/containerd.service
%{_bindir}/*
%dir %{_sharedstatedir}/containerd
%dir %{_sharedstatedir}/containerd/opt
%{_mandir}/man8/containerd.8*
%{_mandir}/man8/containerd-config.8*
%{_mandir}/man8/ctr.8*
%{_mandir}/man5/containerd-config.toml.5*

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6.9-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6.9-3
- Rebuilt for OpenCloudOS Stream 23

* Fri Dec 16 2022 Shuo Wang <abushwang@tencent.com> - 1.6.9-2
- enable debuginfo pkg

* Wed Dec 14 2022 Shuo Wang <abushwang@tencent.com> - 1.6.9-1
- initial build

